==> xpi-speed-dial-0.9.0.8.tbz: lib/xpi/{64161300-e22b-11db-8314-0800200c9a66}/defaults/preferences/speeddial.js <==
pref("extensions.speeddial.thumbnailImageWidth", 400);
pref("extensions.speeddial.thumbnailImageHeight", 400);
pref("extensions.speeddial.backgroundBrowserWidth", 800);
pref("extensions.speeddial.backgroundBrowserHeight", 600);
pref("extensions.speeddial.loadInNewWindow", true);
pref("extensions.speeddial.loadInNewTab", true);
pref("extensions.speeddial.loadInLastTab", true);
pref("extensions.speeddial.showInTabContextMenu", false);
pref("extensions.speeddial.showInAreaContextMenu", false);
pref("extensions.speeddial.showInBookmarksMenu", true);
pref("extensions.speeddial.overrideCtrlNumber", true);
pref("extensions.speeddial.clearURLBarOnLoad", true);
pref("extensions.speeddial.focusURLBarOnLoad", true);
pref("extensions.speeddial.focusContentOnLoad", false);
pref("extensions.speeddial.defaultRefreshInterval", 86400);
pref("extensions.speeddial.thumbnailTooltipTitle", true);
pref("extensions.speeddial.thumbnailTooltipURL", true);
pref("extensions.speeddial.thumbnailDragDropExclude", false);
pref("extensions.speeddial.captureDelay", 1200);
pref("extensions.speeddial.captureTimeout", 30000);
pref("extensions.speeddial.currentVersion", "none");
pref("extensions.speeddial.firstRunRedirection", true);
pref("extensions.speeddial.thumbnailSequentialUpdate", false);
pref("extensions.speeddial.defaultDialJavascript", false);
pref("extensions.speeddial.disableBackgroundBrowserJavascript", false);
pref("extensions.speeddial.disableBackgroundBrowserPlugins", true);
pref("extensions.speeddial.disableBackgroundBrowserAuth", true);
pref("extensions.speeddial.mouseOverThumbnailButtons", true);
pref("extensions.speeddial.showThumbnailReloadButton", true);
pref("extensions.speeddial.showThumbnailDeassignButton", false);
pref("extensions.speeddial.showThumbnailOpenButton", false);
pref("extensions.speeddial.showThumbnailBackgroundTabButton", false);
pref("extensions.speeddial.showThumbnailNewTabButton", false);
pref("extensions.speeddial.showThumbnailNewWindowButton", false);
pref("extensions.speeddial.showThumbnailEditButton", true);
pref("extensions.speeddial.wheelScrollAmount", 10);
pref("extensions.speeddial.columns", 3);
pref("extensions.speeddial.rows", 3);
pref("extensions.speeddial.popupOptionsAccess", true);
pref("extensions.speeddial.enableCache", true);
pref("extensions.speeddial.ctrlShortcutAction", 1);
pref("extensions.speeddial.ctrlShiftShortcutAction", 2);
pref("extensions.speeddial.altShortcutAction", 6);
pref("extensions.speeddial.altShiftShortcutAction", 0);
pref("extensions.speeddial.ctrlAltShiftShortcutAction", 0);
pref("extensions.speeddial.leftClickAction", 1);
pref("extensions.speeddial.middleClickAction", 3);
pref("extensions.speeddial.rightClickAction", 6);
pref("extensions.speeddial.shiftLeftClickAction", 4);
pref("extensions.speeddial.shiftMiddleClickAction", 2);
pref("extensions.speeddial.shiftRightClickAction", 6);
pref("extensions.speeddial.controlLeftClickAction", 3);
pref("extensions.speeddial.controlMiddleClickAction", 3);
pref("extensions.speeddial.controlRightClickAction", 6);
pref("extensions.speeddial.altLeftClickAction", 5);
pref("extensions.speeddial.altMiddleClickAction", 3);
pref("extensions.speeddial.altRightClickAction", 6);
pref("extensions.speeddial.imageFormat", "png");
pref("extensions.speeddial.minimumWidth", 200);
pref("extensions.speeddial.widthModifier", 100);
pref("extensions.speeddial.widthModifierType", 0);
pref("extensions.speeddial.maximumWidth", -1);
pref("extensions.speeddial.minimumHeight", 200);
pref("extensions.speeddial.heightModifier", 100);
pref("extensions.speeddial.heightModifierType", 0);
pref("extensions.speeddial.maximumHeight", -1);
pref("extensions.speeddial.sidebarColumns", 1);
pref("extensions.speeddial.sidebarThumbnailProportion", "1.333");
pref("extensions.speeddial.urlBarShortcuts", true);
pref("extensions.speeddial.openExistingFirst", true);
pref("extensions.speeddial.oldResampling", false);
pref("extensions.speeddial.useJava", false);
pref("extensions.speeddial.preScaling", true);
pref("extensions.speeddial.hideThumbnailNumbers", false);
pref("extensions.speeddial.hideThumbnailIcons", false);
pref("extensions.speeddial.ctrlShortcutMultikey", true);
pref("extensions.speeddial.ctrlShiftShortcutMultikey", true);
pref("extensions.speeddial.altShortcutMultikey", true);
pref("extensions.speeddial.altShiftShortcutMultikey", true);
pref("extensions.speeddial.ctrlAltShiftShortcutMultikey", true);
pref("extensions.speeddial.enableGroups", true);
pref("extensions.speeddial.numGroups", 1);
pref("extensions.speeddial.colorizeTabs", true);
pref("extensions.speeddial.multikeyForSingleDigit", false);
pref("extensions.speeddial.multikeySelectWhenComplete", false);
pref("extensions.speeddial.multikeyOverlayWidthModifier", 80);
pref("extensions.speeddial.useKeyCapture", false);
pref("extensions.speeddial.openOnBlankTab", true);
pref("extensions.speeddial.rememberTabLastGroup", true);
pref("extensions.speeddial.reorderDialsAfterGroupDelete", true);
pref("extensions.speeddial.askBeforeRemovingGroup", true);
pref("extensions.speeddial.zeroStartsMultiKey", false);
pref("extensions.speeddial.ignoreZeroKey", true);
pref("extensions.speeddial.ignoreFileDrops", true);
pref("extensions.speeddial.ignoreRedirects", false);
pref("extensions.speeddial.errorWhenTimeout", true);
pref("extensions.speeddial.useIframe", false);
pref("extensions.speeddial.cloakEvents", false);
pref("extensions.speeddial.buttonOpensInCurrentTab", false);
pref("extensions.speeddial.focusElement", 0);
pref("extensions.speeddial.flexibleTabBar", false);

pref("extensions.{64161300-e22b-11db-8314-0800200c9a66}.description", "chrome://speeddial/locale/speeddial.properties");

==> xpi-speed-dial-0.9.5.2.tbz: lib/xpi/{64161300-e22b-11db-8314-0800200c9a66}/defaults/preferences/speeddial.js <==
pref("extensions.speeddial.thumbnailImageWidth", 400);
pref("extensions.speeddial.thumbnailImageHeight", 400);
pref("extensions.speeddial.backgroundBrowserWidth", 800);
pref("extensions.speeddial.backgroundBrowserHeight", 600);
pref("extensions.speeddial.loadInNewWindow", true);
pref("extensions.speeddial.loadInNewTab", true);
pref("extensions.speeddial.loadInLastTab", true);
pref("extensions.speeddial.showInTabContextMenu", false);
pref("extensions.speeddial.showInAreaContextMenu", false);
pref("extensions.speeddial.showInBookmarksMenu", true);
pref("extensions.speeddial.overrideCtrlNumber", true);
pref("extensions.speeddial.clearURLBarOnLoad", true);
pref("extensions.speeddial.focusURLBarOnLoad", true);
pref("extensions.speeddial.focusContentOnLoad", false);
pref("extensions.speeddial.defaultRefreshInterval", 86400);
pref("extensions.speeddial.thumbnailTooltipTitle", true);
pref("extensions.speeddial.thumbnailTooltipURL", true);
pref("extensions.speeddial.thumbnailDragDropExclude", false);
pref("extensions.speeddial.captureDelay", 1200);
pref("extensions.speeddial.captureTimeout", 30000);
pref("extensions.speeddial.currentVersion", "none");
pref("extensions.speeddial.firstRunRedirection", true);
pref("extensions.speeddial.thumbnailSequentialUpdate", false);
pref("extensions.speeddial.defaultDialJavascript", false);
pref("extensions.speeddial.disableBackgroundBrowserJavascript", false);
pref("extensions.speeddial.disableBackgroundBrowserPlugins", true);
pref("extensions.speeddial.disableBackgroundBrowserAuth", true);
pref("extensions.speeddial.mouseOverThumbnailButtons", true);
pref("extensions.speeddial.mouseOverThumbnailButtonsHighlight", true);
pref("extensions.speeddial.showThumbnailReloadButton", true);
pref("extensions.speeddial.showThumbnailDeassignButton", false);
pref("extensions.speeddial.showThumbnailOpenButton", false);
pref("extensions.speeddial.showThumbnailBackgroundTabButton", false);
pref("extensions.speeddial.showThumbnailNewTabButton", false);
pref("extensions.speeddial.showThumbnailNewWindowButton", false);
pref("extensions.speeddial.showThumbnailEditButton", true);
pref("extensions.speeddial.wheelScrollAmount", 10);
pref("extensions.speeddial.columns", 3);
pref("extensions.speeddial.rows", 3);
pref("extensions.speeddial.popupOptionsAccess", true);
pref("extensions.speeddial.enableCache", true);
pref("extensions.speeddial.ctrlShortcutAction", 1);
pref("extensions.speeddial.ctrlShiftShortcutAction", 2);
pref("extensions.speeddial.altShortcutAction", 0);
pref("extensions.speeddial.altShiftShortcutAction", 0);
pref("extensions.speeddial.ctrlAltShiftShortcutAction", 0);
pref("extensions.speeddial.leftClickAction", 1);
pref("extensions.speeddial.middleClickAction", 3);
pref("extensions.speeddial.rightClickAction", 6);
pref("extensions.speeddial.shiftLeftClickAction", 4);
pref("extensions.speeddial.shiftMiddleClickAction", 2);
pref("extensions.speeddial.shiftRightClickAction", 6);
pref("extensions.speeddial.controlLeftClickAction", 3);
pref("extensions.speeddial.controlMiddleClickAction", 3);
pref("extensions.speeddial.controlRightClickAction", 6);
pref("extensions.speeddial.altLeftClickAction", 5);
pref("extensions.speeddial.altMiddleClickAction", 3);
pref("extensions.speeddial.altRightClickAction", 6);
pref("extensions.speeddial.imageFormat", "png");
pref("extensions.speeddial.minimumWidth", 200);
pref("extensions.speeddial.widthModifier", 100);
pref("extensions.speeddial.widthModifierType", 0);
pref("extensions.speeddial.maximumWidth", -1);
pref("extensions.speeddial.minimumHeight", 200);
pref("extensions.speeddial.heightModifier", 100);
pref("extensions.speeddial.heightModifierType", 0);
pref("extensions.speeddial.maximumHeight", -1);
pref("extensions.speeddial.sidebarColumns", 1);
pref("extensions.speeddial.sidebarThumbnailProportion", "1.333");
pref("extensions.speeddial.urlBarShortcuts", true);
pref("extensions.speeddial.openExistingFirst", true);
pref("extensions.speeddial.oldResampling", false);
pref("extensions.speeddial.useJava", false);
pref("extensions.speeddial.preScaling", true);
pref("extensions.speeddial.hideThumbnailNumbers", false);
pref("extensions.speeddial.hideThumbnailIcons", false);
pref("extensions.speeddial.ctrlShortcutMultikey", true);
pref("extensions.speeddial.ctrlShiftShortcutMultikey", true);
pref("extensions.speeddial.altShortcutMultikey", true);
pref("extensions.speeddial.altShiftShortcutMultikey", true);
pref("extensions.speeddial.ctrlAltShiftShortcutMultikey", true);
pref("extensions.speeddial.enableGroups", true);
pref("extensions.speeddial.numGroups", 1);
pref("extensions.speeddial.colorizeTabs", true);
pref("extensions.speeddial.multikeyForSingleDigit", false);
pref("extensions.speeddial.multikeySelectWhenComplete", false);
pref("extensions.speeddial.multikeyOverlayWidthModifier", 80);
pref("extensions.speeddial.useKeyCapture", false);
pref("extensions.speeddial.openOnBlankTab", true);
pref("extensions.speeddial.rememberTabLastGroup", true);
pref("extensions.speeddial.reorderDialsAfterGroupDelete", true);
pref("extensions.speeddial.askBeforeRemovingGroup", true);
pref("extensions.speeddial.zeroStartsMultiKey", false);
pref("extensions.speeddial.ignoreZeroKey", true);
pref("extensions.speeddial.ignoreFileDrops", true);
pref("extensions.speeddial.ignoreRedirects", false);
pref("extensions.speeddial.errorWhenTimeout", true);
pref("extensions.speeddial.useIframe", false);
pref("extensions.speeddial.cloakEvents", false);
pref("extensions.speeddial.buttonOpensInCurrentTab", false);
pref("extensions.speeddial.focusElement", 0);
pref("extensions.speeddial.flexibleTabBar", false);
pref("extensions.speeddial.rememberLastGroup", false);
pref("extensions.speeddial.lastGroup", 0);
pref("extensions.speeddial.numBackups", -1);

pref("extensions.{64161300-e22b-11db-8314-0800200c9a66}.description", "chrome://speeddial/locale/speeddial.properties");
